@@ -1,7 +1,7 @@
 from google.cloud.workflows.executions_v1beta.services.executions import ExecutionsClient
 
 SYNCHRONIZER_NAME = "synchronizer_workflow"
-DASHBORD_ORCH_NAME = "dahsboard_orch"
+DASHBORD_ORCH_NAME = "dashboard_orch"
 
 
 class Client(ExecutionsClient):
